import { SortDirection, Table } from "morse-react";
import React, { ComponentProps, ComponentType } from "react";
import { PluginDefinition, TablePluginOptions } from "../plugins/PluginDefinition";
import { ColumnDefinition } from "./columns/ColumnDefinition";
export interface DatasetTableProps<T, SortType = keyof T> extends ComponentProps<typeof Table> {
    /**
     * The data set to display - a simple array.
     */
    dataset: T[];
    /**
     * Property names that are sortable.
     *
     * This is an alternative form of setting
     * columns to sortable to avoid needing to switch each column into a
     * full `ColumnDefinition` just to enable sorting.
     */
    sortableProperties?: Array<SortType | keyof T>;
    /**
     * Array of objects to allow `BoundDatasetTableColumns` to infer ability to
     * sort and sort direction, if any.
     *
     * Can be overridden by any setting `sortable` and `sortDirection` in any
     * given `BoundDatasetTableColumn`'s configuration in the `headingProps`
     * config.
     */
    sorts?: Array<{
        property: SortType;
        direction?: SortDirection;
    }>;
    onSortDirectionChange?: (property: SortType, newDirection: SortDirection) => void;
    /**
     * An array of DatasetTableColumns that describes the column configuration
     */
    columns: Array<ColumnDefinition<T, SortType> | keyof T>;
    /**
     * An optional function to handle rending of a row of items.
     *
     * Allows for extended behaviours that might need to inject secondary rows.
     */
    rowRender?: (item: T, rowElements: Array<JSX.Element | null>, index: number) => React.ReactNode;
    /** Event handler attached to each `tr` element (with the exception of the heading row) */
    onRowClick?: (item: T) => void;
    /**
     * When set, the contents of each cell will be wrapped in a React Router `<Link>` component to allow browser based
     * linking, rather than `history.push()` or other alternative methods.
     */
    rowLinkTo?: (item: T) => string;
    /**
     * Appends a row to the bottom of the table without the dataset specific click handlers/props.
     *
     * Note that the footer is automatically surrounded with <TableFoot> to be semantically correct.
     */
    footer?: React.ReactNode;
    /**
     * Adds additional content to the header of the table without the dataset specific click handlers/props.
     */
    additionalHeaders?: ComponentType[];
    plugins?: PluginDefinition<T, SortType>[];
    pluginOptions?: TablePluginOptions<T>;
}
/**
 * A table component to display tabular data from a data set for a configured list of columns.
 *
 * @param props
 * @returns
 */
export declare const DatasetTable: <T, SortType = keyof T>(props: DatasetTableProps<T, SortType>) => JSX.Element;
